searchData={"items":[{"type":"module","title":"LibNFC","doc":"This package provides a NIF binding to [libnfc](http://www.libnfc.org/) and some Elixir\nboilerplate for convenient & more idiomatic use.","ref":"LibNFC.html"},{"type":"module","title":"Status - LibNFC","doc":"This library was designed to detect and track the presence of ISO/IEC 14443 Type A **passive NFC targets** from an Elixir application. Its original use-case was a Raspberry-based [music box](https://phoniebox.de/) controlled by cheap passive NFC tags detectable by a [PN532 NFC HAT](https://www.waveshare.com/wiki/PN532_NFC_HAT). The adaptation of libnfc functions as well as design of the surrounding Elixir API is so far limited to support this use-case, yet extending the library for other NFC modulations should be relatively straightforward.\n\n- ✅ Listing & opening NFC devices\n- ✅ ISO 14333 Type A passive target selecting & tracking\n\nNot implemented:\n\n- Other modulations\n- Initiator API: Polling, writing, transceiving\n- Target API","ref":"LibNFC.html#module-status"},{"type":"module","title":"Dependencies - LibNFC","doc":"- libnfc\n- make\n- working C11 compiler, e.g. gcc\n\n#","ref":"LibNFC.html#module-dependencies"},{"type":"module","title":"Installing libnfc from source - LibNFC","doc":"On Debian and derived Linux systems:\n\n```\nsudo apt-get install build-essentials automake autoconf\nsudo apt-get install libusb-dev\n```\n\n```\ngit clone https://github.com/nfc-tools/libnfc\ncd libnfc\nautoreconf -vis\n./configure --prefix=/usr --sysconfdir=/etc\nmake -j4\nsudo make install\n```\n\nVisit [libnfc](https://github.com/nfc-tools/libnfc#installation) for details.","ref":"LibNFC.html#module-installing-libnfc-from-source"},{"type":"module","title":"Installation - LibNFC","doc":"```elixir\ndef deps do\n  [\n    {:libnfc_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"LibNFC.html#module-installation"},{"type":"module","title":"Usage - LibNFC","doc":"```elixir\n{:ok, device} = LibNFC.open()\n\n{:ok, target_info} =\n  LibNFC.initiator_select_passive_target(device)\n\nIO.puts(\"Target #{LibNFC.Utils.uid_hex(target_info[\"uid\"])} in range\")\n```","ref":"LibNFC.html#module-usage"},{"type":"function","title":"LibNFC.initiator_select_passive_target/2","doc":"Tries to select a passive target with a given modulation.","ref":"LibNFC.html#initiator_select_passive_target/2"},{"type":"function","title":"LibNFC.initiator_target_is_present?/1","doc":"Checks whether a previously selected target is still present.","ref":"LibNFC.html#initiator_target_is_present?/1"},{"type":"function","title":"LibNFC.list_devices/0","doc":"Lists NFC devices controlled by operating system.","ref":"LibNFC.html#list_devices/0"},{"type":"function","title":"LibNFC.open/0","doc":"Opens the default NFC device.","ref":"LibNFC.html#open/0"},{"type":"function","title":"LibNFC.open/1","doc":"Opens a specific NFC device identified by a \"connstring\".","ref":"LibNFC.html#open/1"},{"type":"function","title":"LibNFC.version/0","doc":"Returns version of linked libnfc library.","ref":"LibNFC.html#version/0"},{"type":"type","title":"LibNFC.device/0","doc":"Reference of opened NFC device.","ref":"LibNFC.html#t:device/0"},{"type":"type","title":"LibNFC.modulation/0","doc":"Short identifier for types of NFC targets. Defines both modulation & baud rate.\n\nSee `nfc_baud_rate` and `nfc_modulation_type` in [`nfc_types.h`](http://www.libnfc.org/api/nfc-types_8h_source.html).","ref":"LibNFC.html#t:modulation/0"},{"type":"type","title":"Known types - LibNFC.modulation/0","doc":"- `:iso14443a` -> `NMT_ISO14443A`, `NBR_106`","ref":"LibNFC.html#t:modulation/0-known-types"},{"type":"type","title":"LibNFC.target_info/0","doc":"Map of data received from NFC target.\n\nStructure is determined by NFC target type.\n\nSee `nfc_target_info` union in [`nfc_types.h`](http://www.libnfc.org/api/nfc-types_8h_source.html).","ref":"LibNFC.html#t:target_info/0"},{"type":"module","title":"LibNFC.Logger","doc":"Sample logger implementation of `LibNFC.Presence` behaviour.","ref":"LibNFC.Logger.html"},{"type":"function","title":"LibNFC.Logger.child_spec/1","doc":"","ref":"LibNFC.Logger.html#child_spec/1"},{"type":"function","title":"LibNFC.Logger.start_link/1","doc":"","ref":"LibNFC.Logger.html#start_link/1"},{"type":"module","title":"LibNFC.Mock","doc":"NFC device emulation for testing purposes without physical interaction with a NFC device.\n\nThis module allows to emulate the presence of NFC targets in range of a \"mock\" device.\n`LibNFC.Mock` is a GenServer (to be spawned within a supervision tree) that holds the status\nof NFC targets in range. Functions on `LibNFC` accepting a `:mock` parameter instead of the\nNFC device reference will fetch data from this server instead of actually talking to libnfc.","ref":"LibNFC.Mock.html"},{"type":"function","title":"LibNFC.Mock.clear_target/0","doc":"Removes the NFC target.","ref":"LibNFC.Mock.html#clear_target/0"},{"type":"function","title":"LibNFC.Mock.put_target/2","doc":"Puts a NFC target in range.","ref":"LibNFC.Mock.html#put_target/2"},{"type":"function","title":"LibNFC.Mock.start_link/1","doc":"Starts the mock process.","ref":"LibNFC.Mock.html#start_link/1"},{"type":"type","title":"LibNFC.Mock.modulation/0","doc":"","ref":"LibNFC.Mock.html#t:modulation/0"},{"type":"type","title":"LibNFC.Mock.server_options/0","doc":"Server options\n\n* `nif_delay` emulates delay of NIF calls (default: 400)\n* `nif_delay_jitter` jitter factor for delay (default: 0.5)","ref":"LibNFC.Mock.html#t:server_options/0"},{"type":"type","title":"LibNFC.Mock.target/0","doc":"","ref":"LibNFC.Mock.html#t:target/0"},{"type":"type","title":"LibNFC.Mock.target_info/0","doc":"","ref":"LibNFC.Mock.html#t:target_info/0"},{"type":"behaviour","title":"LibNFC.Presence","doc":"Passive tag monitor process.\n\n- Repeatedly polls for passive targets in range.\n- Emits an event when target enters.\n- Emits another event when target leaves.\n\nTarget presence is tracked by polling `nfc_initiator_target_is_present` with a short debounce.","ref":"LibNFC.Presence.html"},{"type":"behaviour","title":"Usage - LibNFC.Presence","doc":"defmodule MyApp.NFC do\n      use LibNFC.Presence\n\n      @impl true\n      def handle_target_in(target, state) do\n        # ...\n        {:ok, state}\n      end\n\n      @impl true\n      def handle_target_out(state) do\n        # ...\n        {:ok, state}\n      end\n    end\n\n    defmodule MyApp.Application do\n      def start(_, _) do\n        children = [\n          ...\n          {MyApp.NFC, client_state: :foo}\n        ]\n\n        Supervisor.start_link(...)\n      end\n    end","ref":"LibNFC.Presence.html#module-usage"},{"type":"function","title":"LibNFC.Presence.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LibNFC.Presence.html#child_spec/1"},{"type":"callback","title":"LibNFC.Presence.handle_target_in/2","doc":"Emitted when a passive target is detected.","ref":"LibNFC.Presence.html#c:handle_target_in/2"},{"type":"callback","title":"LibNFC.Presence.handle_target_out/1","doc":"Emitted when selected target left.","ref":"LibNFC.Presence.html#c:handle_target_out/1"},{"type":"callback","title":"LibNFC.Presence.open_device/1","doc":"Called on process initialization to open the NFC reader device.\n\nOptional callback. Defaults to opening the \"first\" device found by calling `nfc_open` without\na connstring.","ref":"LibNFC.Presence.html#c:open_device/1"},{"type":"function","title":"LibNFC.Presence.start_link/2","doc":"Starts the passive tag monitor process.","ref":"LibNFC.Presence.html#start_link/2"},{"type":"type","title":"LibNFC.Presence.client_state/0","doc":"Arbitrary client state held within the presence monitor process.","ref":"LibNFC.Presence.html#t:client_state/0"},{"type":"type","title":"LibNFC.Presence.server_options/0","doc":"Server Options\n\n* `client_state` initial client state (default: nil)\n* `mock` when set to true, default device will be the mock (default: false)\n* `schedule_delay` poll interval in ms (default: 300)\n* `alive_after_last_seen` debounce leave event for a short period as some calls to\n  `nfc_initiator_target_is_present` come back as false negatives (default: 500)","ref":"LibNFC.Presence.html#t:server_options/0"},{"type":"module","title":"LibNFC.Utils","doc":"Utilities for working with NFC targets.","ref":"LibNFC.Utils.html"},{"type":"function","title":"LibNFC.Utils.uid_hex/1","doc":"Returns hexadecimal representation of UID of a NFC target.","ref":"LibNFC.Utils.html#uid_hex/1"},{"type":"extras","title":"README","doc":"<!-- SPDX-License-Identifier: Apache-2.0 -->\n\n# `libnfc_ex`\n\n<!-- MDOC -->\n\nThis package provides a NIF binding to [libnfc](http://www.libnfc.org/) and some Elixir\nboilerplate for convenient & more idiomatic use.","ref":"readme.html"},{"type":"extras","title":"Status - README","doc":"This library was designed to detect and track the presence of ISO/IEC 14443 Type A **passive NFC targets** from an Elixir application. Its original use-case was a Raspberry-based [music box](https://phoniebox.de/) controlled by cheap passive NFC tags detectable by a [PN532 NFC HAT](https://www.waveshare.com/wiki/PN532_NFC_HAT). The adaptation of libnfc functions as well as design of the surrounding Elixir API is so far limited to support this use-case, yet extending the library for other NFC modulations should be relatively straightforward.\n\n- ✅ Listing & opening NFC devices\n- ✅ ISO 14333 Type A passive target selecting & tracking\n\nNot implemented:\n\n- Other modulations\n- Initiator API: Polling, writing, transceiving\n- Target API","ref":"readme.html#status"},{"type":"extras","title":"Dependencies - README","doc":"- libnfc\n- make\n- working C11 compiler, e.g. gcc\n\n#","ref":"readme.html#dependencies"},{"type":"extras","title":"Installing libnfc from source - README","doc":"On Debian and derived Linux systems:\n\n```\nsudo apt-get install build-essentials automake autoconf\nsudo apt-get install libusb-dev\n```\n\n```\ngit clone https://github.com/nfc-tools/libnfc\ncd libnfc\nautoreconf -vis\n./configure --prefix=/usr --sysconfdir=/etc\nmake -j4\nsudo make install\n```\n\nVisit [libnfc](https://github.com/nfc-tools/libnfc#installation) for details.","ref":"readme.html#installing-libnfc-from-source"},{"type":"extras","title":"Installation - README","doc":"```elixir\ndef deps do\n  [\n    {:libnfc_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"```elixir\n{:ok, device} = LibNFC.open()\n\n{:ok, target_info} =\n  LibNFC.initiator_select_passive_target(device)\n\nIO.puts(\"Target #{LibNFC.Utils.uid_hex(target_info[\"uid\"])} in range\")\n```\n\n<!-- MDOC -->","ref":"readme.html#usage"},{"type":"extras","title":"Alternatives - README","doc":"- [`nerves_io_nfc`](https://github.com/arjan/nerves_io_nfc) has similar scope but is tied to Nerves","ref":"readme.html#alternatives"},{"type":"extras","title":"Changelog","doc":"# Unreleased\n\n- First release of library\n- NIF interface to [libnfc](http://www.libnfc.org/)\n- Support ISO 14443A passive tags\n- `LibNFC.Presence` monitor for tracking tags","ref":"changelog.html"},{"type":"extras","title":"License","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}